@@ -23,6 +23,7 @@ HTML_REPORT_HELP = "Diff coverage HTML output"
 COMPARE_BRANCH_HELP = "Branch to compare"
 VIOLATION_CMD_HELP = "Which code quality tool to use"
 INPUT_REPORTS_HELP = "Pep8 or pylint reports to use"
+OPTIONS_HELP = "Options to be passed to the violations tool"
 
 QUALITY_REPORTERS = {
     'pep8': Pep8QualityReporter,
@@ -119,6 +120,14 @@ def parse_quality_args(argv):
         help=INPUT_REPORTS_HELP
     )
 
+    parser.add_argument(
+        '--options',
+        type=str,
+        nargs='?',
+        default=None,
+        help=OPTIONS_HELP
+    )
+
     return vars(parser.parse_args(argv))
 
 
@@ -135,7 +144,7 @@ def generate_coverage_report(coverage_xml, compare_branch, html_report=None):
     # Build a report generator
     if html_report is not None:
         reporter = HtmlReportGenerator(coverage, diff)
-        output_file = open(html_report, "w")
+        output_file = open(html_report, "wb")
     else:
         reporter = StringReportGenerator(coverage, diff)
         output_file = sys.stdout
@@ -152,7 +161,7 @@ def generate_quality_report(tool, compare_branch, html_report=None):
 
     if html_report is not None:
         reporter = HtmlQualityReportGenerator(tool, diff)
-        output_file = open(html_report, "w")
+        output_file = open(html_report, "wb")
     else:
         reporter = StringQualityReportGenerator(tool, diff)
         output_file = sys.stdout
@@ -177,6 +186,9 @@ def main():
     elif progname.endswith('diff-quality'):
         arg_dict = parse_quality_args(sys.argv[1:])
         tool = arg_dict['violations']
+        user_options = arg_dict.get('options')
+        if user_options:
+            user_options = user_options[1:-1]  # Strip quotes
         reporter_class = QUALITY_REPORTERS.get(tool)
 
         if reporter_class is not None:
@@ -191,7 +203,7 @@ def main():
                     LOGGER.warning("Could not load '{0}'".format(path))
 
             try:
-                reporter = reporter_class(tool, input_reports)
+                reporter = reporter_class(tool, input_reports, user_options=user_options)
                 generate_quality_report(
                     reporter,
                     arg_dict['compare_branch'],
